@@ -1,37 +1,15 @@
 import os
 import sys
-from setuptools import Command
 from distutils import log
 from distutils.command.clean import clean
 from os.path import exists
 from shutil import rmtree
-from typing import Any
 from uuid import UUID, uuid4
 
-import six
+from setuptools import Command
 
 
-def raisefrom(exc_type, message, exc):
-    # type: (Any, str, BaseException) -> None
-    """Call Python 3 raise from or emulate it for Python 2
-
-    Args:
-        exc_type (Any): Type of Exception
-        message (str): Error message to display
-        exc (BaseException): original exception
-
-    Returns:
-        None
-
-    """
-    if sys.version_info[:2] >= (3, 2):
-        six.raise_from(exc_type(message), exc)
-    else:
-        six.reraise(exc_type, '%s - %s' % (message, exc), sys.exc_info()[2])
-
-
-def get_uuid():
-    # type: () -> str
+def get_uuid() -> str:
     """
     Get an UUID.
 
@@ -41,8 +19,7 @@ def get_uuid():
     return str(uuid4())
 
 
-def is_valid_uuid(uuid_to_test, version=4):
-    # type: (str, int) -> bool
+def is_valid_uuid(uuid_to_test: str, version: int = 4) -> bool:
     """
     Check if uuid_to_test is a valid UUID.
 
@@ -68,8 +45,8 @@ class CleanCommand(clean):
         """After calling the super class implementation, this function removes
         the dist directory if it exists."""
         self.all = True  # --all by default when cleaning
-        super(CleanCommand, self).run()
-        dir_ = 'dist'
+        super().run()
+        dir_ = "dist"
         if exists(dir_):
             log.info("removing '%s' (and everything under it)", dir_)
             rmtree(dir_)
@@ -80,7 +57,7 @@ class CleanCommand(clean):
 class PackageCommand(Command):
     """Package command for setup.py that creates source and wheel packages."""
 
-    description = 'Build the packages.'
+    description = "Build the packages."
     user_options = []
 
     def initialize_options(self):
@@ -90,8 +67,8 @@ class PackageCommand(Command):
         pass
 
     def run(self):
-        log.info('Building Source and Wheel (universal) Packages...')
-        os.system('{0} setup.py clean sdist bdist_wheel --universal'.format(sys.executable))
+        log.info("Building Source and Wheel (universal) Packages...")
+        os.system(f"{sys.executable} setup.py clean sdist bdist_wheel --universal")
         sys.exit()
 
 
@@ -100,7 +77,7 @@ class PublishCommand(Command):
     Requires that twine and git be installed."""
 
     version = None
-    description = 'Publish the packages.'
+    description = "Publish the packages."
     user_options = []
 
     def initialize_options(self):
@@ -110,12 +87,12 @@ class PublishCommand(Command):
         pass
 
     def run(self):
-        log.info('Uploading the package to PyPI using twine...')
-        os.system('twine upload dist/*')
+        log.info("Uploading the package to PyPI using twine...")
+        os.system("twine upload dist/*")
 
         if PublishCommand.version:
-            log.info('Pushing git tags...')
-            os.system('git tag v{0}'.format(PublishCommand.version))
-            os.system('git push --tags')
+            log.info("Pushing git tags...")
+            os.system(f"git tag v{PublishCommand.version}")
+            os.system("git push --tags")
 
         sys.exit()
