@@ -1,15 +1,15 @@
-# -*- coding: utf-8 -*-
 """Directory Path Utilities"""
 import contextlib
 import inspect
 import logging
 import sys
 from os import getenv, makedirs, remove
-from os.path import abspath, realpath, dirname, join, exists
+from os.path import abspath, dirname, exists, join, realpath, splitext
+from posixpath import basename
 from shutil import rmtree
 from tempfile import gettempdir
-
-from typing import Any, Optional, Iterable, Tuple, Dict, List
+from typing import Any, Dict, Iterable, List, Optional, Tuple
+from urllib.parse import urlsplit
 
 from hdx.utilities import get_uuid
 from hdx.utilities.loader import load_file_to_str
@@ -22,8 +22,7 @@ class NotFoundError(Exception):
     pass
 
 
-def script_dir(pyobject, follow_symlinks=True):
-    # type: (Any, bool) -> str
+def script_dir(pyobject: Any, follow_symlinks: bool = True) -> str:
     """Get current script's directory
 
     Args:
@@ -33,8 +32,8 @@ def script_dir(pyobject, follow_symlinks=True):
     Returns:
         str: Current script's directory
     """
-    if getattr(sys, 'frozen', False):  # py2exe, PyInstaller, cx_Freeze
-        path = abspath(sys.executable)   # pragma: no cover
+    if getattr(sys, "frozen", False):  # py2exe, PyInstaller, cx_Freeze
+        path = abspath(sys.executable)  # pragma: no cover
     else:
         path = inspect.getabsfile(pyobject)
     if follow_symlinks:
@@ -42,8 +41,9 @@ def script_dir(pyobject, follow_symlinks=True):
     return dirname(path)
 
 
-def script_dir_plus_file(filename, pyobject, follow_symlinks=True):
-    # type: (str, Any, bool) -> str
+def script_dir_plus_file(
+    filename: str, pyobject: Any, follow_symlinks: bool = True
+) -> str:
     """Get current script's directory and then append a filename
 
     Args:
@@ -57,8 +57,11 @@ def script_dir_plus_file(filename, pyobject, follow_symlinks=True):
     return join(script_dir(pyobject, follow_symlinks), filename)
 
 
-def get_temp_dir(folder=None, delete_if_exists=False, tempdir=None):
-    # type: (Optional[str], bool, Optional[str]) -> str
+def get_temp_dir(
+    folder: Optional[str] = None,
+    delete_if_exists: bool = False,
+    tempdir: Optional[str] = None,
+) -> str:
     """Get a temporary directory. Looks for environment variable TEMP_DIR and falls
     back on os.gettempdir if a root temporary directory is not supplied. If a folder is supplied, creates that folder
     within the temporary directory. Optionally deletes and recreates it if it already exists.
@@ -72,7 +75,7 @@ def get_temp_dir(folder=None, delete_if_exists=False, tempdir=None):
         str: A temporary directory
     """
     if tempdir is None:
-        tempdir = getenv('TEMP_DIR', gettempdir())
+        tempdir = getenv("TEMP_DIR", gettempdir())
     if folder:
         tempdir = join(tempdir, folder)
         if exists(tempdir):
@@ -85,8 +88,13 @@ def get_temp_dir(folder=None, delete_if_exists=False, tempdir=None):
 
 
 @contextlib.contextmanager
-def temp_dir(folder=None, delete_if_exists=False, delete_on_success=True, delete_on_failure=True, tempdir=None):
-    # type: (Optional[str], bool, bool, bool, Optional[str]) -> str
+def temp_dir(
+    folder: Optional[str] = None,
+    delete_if_exists: bool = False,
+    delete_on_success: bool = True,
+    delete_on_failure: bool = True,
+    tempdir: Optional[str] = None,
+) -> str:
     """Get a temporary directory optionally with folder appended (and created if it doesn't exist)
 
     Args:
@@ -111,8 +119,7 @@ def temp_dir(folder=None, delete_if_exists=False, delete_on_success=True, delete
             raise
 
 
-def read_or_create_batch(folder, batch=None):
-    # type: (str, Optional[str]) -> str
+def read_or_create_batch(folder: str, batch: Optional[str] = None) -> str:
     """Get batch or create it if it doesn't exist
 
     Args:
@@ -122,22 +129,27 @@ def read_or_create_batch(folder, batch=None):
     Returns:
         str: Batch
     """
-    batch_file = join(folder, 'batch.txt')
+    batch_file = join(folder, "batch.txt")
     if exists(batch_file):
         batch = load_file_to_str(batch_file, strip=True)
-        logger.info('File BATCH = %s' % batch)
+        logger.info(f"File BATCH = {batch}")
     else:
         if not batch:
             batch = get_uuid()
-            logger.info('Generated BATCH = %s' % batch)
+            logger.info(f"Generated BATCH = {batch}")
         save_str_to_file(batch, batch_file)
     return batch
 
 
 @contextlib.contextmanager
-def temp_dir_batch(folder=None, delete_if_exists=False, delete_on_success=True, delete_on_failure=True,
-                   batch=None, tempdir=None):
-    # type: (Optional[str], bool, bool, bool, Optional[str], Optional[str]) -> Dict
+def temp_dir_batch(
+    folder: Optional[str] = None,
+    delete_if_exists: bool = False,
+    delete_on_success: bool = True,
+    delete_on_failure: bool = True,
+    batch: Optional[str] = None,
+    tempdir: Optional[str] = None,
+) -> Dict:
     """Get a temporary directory and batch id. Yields a dictionary with key folder which is the temporary directory
     optionally with folder appended (and created if it doesn't exist). In key batch is a batch code to be passed as
     the batch parameter in create_in_hdx or update_in_hdx calls.
@@ -153,12 +165,13 @@ def temp_dir_batch(folder=None, delete_if_exists=False, delete_on_success=True,
     Returns:
         Dict: Dictionary containing temporary directory in key folder and batch id in key batch
     """
-    with temp_dir(folder, delete_if_exists, delete_on_success, delete_on_failure, tempdir=tempdir) as tempdir:
-        yield {'folder': tempdir, 'batch': read_or_create_batch(tempdir, batch)}
+    with temp_dir(
+        folder, delete_if_exists, delete_on_success, delete_on_failure, tempdir=tempdir
+    ) as tempdir:
+        yield {"folder": tempdir, "batch": read_or_create_batch(tempdir, batch)}
 
 
-def get_wheretostart(text, message, key):
-    # type: (str, str, str) -> Optional[str]
+def get_wheretostart(text: str, message: str, key: str) -> Optional[str]:
     """Evaluate WHERETOSTART.
 
     Args:
@@ -170,18 +183,19 @@ def get_wheretostart(text, message, key):
         Optional[str]: A string or None
     """
     upper_text = text.upper()
-    if upper_text == 'RESET':
+    if upper_text == "RESET":
         return None
-    w_key, wheretostart = text.split('=')
+    w_key, wheretostart = text.split("=")
     if w_key == key:
-        logger.info('%s WHERETOSTART = %s' % (message, wheretostart))
+        logger.info(f"{message} WHERETOSTART = {wheretostart}")
         return wheretostart
     else:
-        return 'IGNORE'
+        return "IGNORE"
 
 
-def progress_storing_folder(info, iterator, key, wheretostart=None):
-    # type: (Dict, Iterable[Dict], str, Optional[str]) -> Tuple[Dict,Dict]
+def progress_storing_folder(
+    info: Dict, iterator: Iterable[Dict], key: str, wheretostart: Optional[str] = None
+) -> Tuple[Dict, Dict]:
     """Store progress in folder in key folder of info dictionary parameter. Yields 2 dictionaries. The first is the
     info dictionary. It contains in key folder the folder being used to store progress and in key progress the current
     position in the iterator. If store_batch is True, that dictionary will also contain the key batch containing a batch
@@ -197,44 +211,50 @@ def progress_storing_folder(info, iterator, key, wheretostart=None):
     Returns:
         Tuple[Dict,Dict]: A tuple of the form (info dictionary, next object in iterator)
     """
-    folder = info['folder']
-    progress_file = join(folder, 'progress.txt')
+    folder = info["folder"]
+    progress_file = join(folder, "progress.txt")
 
     if not wheretostart:
-        contents = getenv('WHERETOSTART')
+        contents = getenv("WHERETOSTART")
         if contents:
-            wheretostart = get_wheretostart(contents, 'Environment variable', key)
+            wheretostart = get_wheretostart(contents, "Environment variable", key)
         else:
             if exists(progress_file):
                 contents = load_file_to_str(progress_file, strip=True)
-                wheretostart = get_wheretostart(contents, 'File', key)
+                wheretostart = get_wheretostart(contents, "File", key)
             else:
                 wheretostart = None
     found = False
     for nextdict in iterator:
         current = nextdict[key]
         if wheretostart:
-            if wheretostart == 'IGNORE':
+            if wheretostart == "IGNORE":
                 continue
             if not found:
                 if current == wheretostart:
                     found = True
-                    logger.info('Starting run from WHERETOSTART %s' % wheretostart)
+                    logger.info(f"Starting run from WHERETOSTART {wheretostart}")
                 else:
-                    logger.info('Run not started. Ignoring %s. WHERETOSTART (%s) not matched.' % (current,
-                                                                                                  wheretostart))
+                    logger.info(
+                        "Run not started. Ignoring {}. WHERETOSTART ({}) not matched.".format(
+                            current, wheretostart
+                        )
+                    )
                     continue
-        output = '%s=%s' % (key, current)
-        info['progress'] = output
+        output = f"{key}={current}"
+        info["progress"] = output
         save_str_to_file(output, progress_file)
         yield info, nextdict
     if wheretostart and not found:
-        raise NotFoundError('WHERETOSTART (%s) not matched in iterator with key %s and no run started!' % (wheretostart, key))
+        raise NotFoundError(
+            f"WHERETOSTART ({wheretostart}) not matched in iterator with key {key} and no run started!"
+        )
 
 
 @contextlib.contextmanager
-def wheretostart_tempdir_batch(folder, batch=None, tempdir=None):
-    # type: (str, Optional[str], Optional[str]) -> Dict
+def wheretostart_tempdir_batch(
+    folder: str, batch: Optional[str] = None, tempdir: Optional[str] = None
+) -> Dict:
     """Get a temporary directory and batch id. Deletes any existing folder if WHERETOSTART environment variable is set
     to RESET. Yields a dictionary with key folder which is the temporary directory optionally with folder appended
     (and created if it doesn't exist). In key batch is a batch code to be passed as the batch parameter in
@@ -249,18 +269,29 @@ def wheretostart_tempdir_batch(folder, batch=None, tempdir=None):
         Dict: Dictionary containing temporary directory in key folder and batch id in key batch
     """
     delete_if_exists = False
-    wheretostart = getenv('WHERETOSTART')
+    wheretostart = getenv("WHERETOSTART")
     if wheretostart:
-        if wheretostart.upper() == 'RESET':
+        if wheretostart.upper() == "RESET":
             delete_if_exists = True
-            logger.info('Removing progress file and will start from beginning!')
-    with temp_dir_batch(folder, delete_if_exists, delete_on_success=True, delete_on_failure=False,
-                        batch=batch, tempdir=tempdir) as info:
+            logger.info("Removing progress file and will start from beginning!")
+    with temp_dir_batch(
+        folder,
+        delete_if_exists,
+        delete_on_success=True,
+        delete_on_failure=False,
+        batch=batch,
+        tempdir=tempdir,
+    ) as info:
         yield info
 
 
-def progress_storing_tempdir(folder, iterator, key, batch=None, tempdir=None):
-    # type: (str, Iterable[Dict], str, Optional[str], Optional[str]) -> Tuple[Dict,Dict]
+def progress_storing_tempdir(
+    folder: str,
+    iterator: Iterable[Dict],
+    key: str,
+    batch: Optional[str] = None,
+    tempdir: Optional[str] = None,
+) -> Tuple[Dict, Dict]:
     """Store progress in temporary directory. The folder persists until the final iteration allowing which iteration to
     start at and the batch code to be persisted between runs. Yields 2 dictionaries. The first contains key folder which
     is the temporary directory optionally with folder appended (and created if it doesn't exist). In key progress is
@@ -280,12 +311,15 @@ def progress_storing_tempdir(folder, iterator, key, batch=None, tempdir=None):
         Tuple[Dict,Dict]: A tuple of the form (info dictionary, next object in iterator)
     """
     with wheretostart_tempdir_batch(folder, batch=batch, tempdir=tempdir) as info:
-        for result in progress_storing_folder(info, iterator, key):
-            yield result
+        yield from progress_storing_folder(info, iterator, key)
 
 
-def multiple_progress_storing_tempdir(folder, iterators, keys, batch=None):
-    # type: (str, List[Iterable[Dict]], List[str], Optional[str]) -> Tuple[Dict,Dict]
+def multiple_progress_storing_tempdir(
+    folder: str,
+    iterators: List[Iterable[Dict]],
+    keys: List[str],
+    batch: Optional[str] = None,
+) -> Tuple[Dict, Dict]:
     """Store progress in temporary directory. The folder persists until the final iteration of the last iterator
     allowing which iteration to start at and the batch code to be persisted between runs. Yields 2 dictionaries. The
     first contains key folder which is the temporary directory optionally with folder appended (and created if it
@@ -305,28 +339,71 @@ def multiple_progress_storing_tempdir(folder, iterators, keys, batch=None):
         Tuple[int, Dict,Dict]: A tuple of the form (iterator index, info dictionary, next object in iterator)
     """
     delete_if_exists = False
-    wheretostartenv = getenv('WHERETOSTART')
+    wheretostartenv = getenv("WHERETOSTART")
     if wheretostartenv:
-        if wheretostartenv.upper() == 'RESET':
+        if wheretostartenv.upper() == "RESET":
             delete_if_exists = True
-            logger.info('Removing progress file and will start from beginning!')
-    with temp_dir_batch(folder, delete_if_exists, delete_on_success=True, delete_on_failure=False, batch=batch) as info:
-        tempdir = info['folder']
-        batch = info['batch']
+            logger.info("Removing progress file and will start from beginning!")
+    with temp_dir_batch(
+        folder,
+        delete_if_exists,
+        delete_on_success=True,
+        delete_on_failure=False,
+        batch=batch,
+    ) as info:
+        tempdir = info["folder"]
+        batch = info["batch"]
         for i, key in enumerate(keys):
-            progress_file = join(tempdir, 'progress.txt')
+            progress_file = join(tempdir, "progress.txt")
             if wheretostartenv:
-                wheretostart = get_wheretostart(wheretostartenv, 'Environment variable', key)
+                wheretostart = get_wheretostart(
+                    wheretostartenv, "Environment variable", key
+                )
             else:
                 if exists(progress_file):
                     contents = load_file_to_str(progress_file, strip=True)
-                    wheretostart = get_wheretostart(contents, 'File', key)
+                    wheretostart = get_wheretostart(contents, "File", key)
                 else:
                     wheretostart = None
-            with temp_dir_batch(str(i), False, delete_on_success=True, delete_on_failure=False,
-                                batch=batch, tempdir=tempdir) as info:
-                for info, nextdict in progress_storing_folder(info, iterators[i], key, wheretostart):
-                    save_str_to_file(info['progress'], progress_file)
+            with temp_dir_batch(
+                str(i),
+                False,
+                delete_on_success=True,
+                delete_on_failure=False,
+                batch=batch,
+                tempdir=tempdir,
+            ) as info:
+                for info, nextdict in progress_storing_folder(
+                    info, iterators[i], key, wheretostart
+                ):
+                    save_str_to_file(info["progress"], progress_file)
                     yield i, info, nextdict
                 if exists(progress_file):
                     remove(progress_file)
+
+
+def get_filename_from_url(url: str) -> str:
+    """Get filename including extension from url
+
+    Args:
+        url (str): URL
+
+    Returns:
+        str: filename
+
+    """
+    urlpath = urlsplit(url).path
+    return basename(urlpath)
+
+
+def get_filename_extension_from_url(url: str) -> Tuple[str, str]:
+    """Get separately filename and extension from url
+
+    Args:
+        url (str): URL to download
+
+    Returns:
+        Tuple[str,str]: Tuple of (filename, extension)
+
+    """
+    return splitext(get_filename_from_url(url))
